@@ -2,7 +2,10 @@ pub(crate) mod impls;
 mod inspectable_registry;
 mod plugin;
 
-use bevy::{ecs::archetype::Archetype, render::camera::Camera, ui::FocusPolicy, window::WindowId};
+use bevy::{
+    ecs::archetype::Archetype, reflect::TypeRegistration, render::camera::Camera, ui::FocusPolicy,
+    window::WindowId,
+};
 pub use inspectable_registry::InspectableRegistry;
 pub use plugin::WorldInspectorPlugin;
 
@@ -265,9 +268,8 @@ impl<'a> WorldUIContext<'a> {
         changed
     }
 
-    /// Safety:
-    /// `entity_location` must point to a valid archetype and index.
-    fn component_kind_ui(
+    /// Displays the components of an entity
+    pub fn component_kind_ui(
         &mut self,
         ui: &mut egui::Ui,
         components: impl Fn(&Archetype) -> &[ComponentId],
@@ -402,29 +404,30 @@ impl<'a> WorldUIContext<'a> {
                     ui.set_enabled(false);
                 }
 
-                let result = self.world
-                    .resource_scope(|world, inspectable_registry: Mut<InspectableRegistry>| {
+                let result = self.world.resource_scope(
+                    |world, inspectable_registry: Mut<InspectableRegistry>| {
                         world.resource_scope(|world, type_registry: Mut<TypeRegistryArc>| {
-                        let type_registry = &*type_registry.internal.read();
+                            let type_registry = &*type_registry.internal.read();
 
-                        // Safety: according to this function's contract, entity_location (and therefore component_ptr) are valid
-                        try_display(
-                            world,
-                            entity,
-                            component_ptr,
-                            is_zst,
-                            type_id,
-                            &*inspectable_registry,
-                            type_registry,
-                            ui,
-                            self.ui_ctx,
-                            id,
-                        )
-                    })
-                });
+                            // Safety: according to this function's contract, entity_location (and therefore component_ptr) are valid
+                            try_display(
+                                world,
+                                entity,
+                                component_ptr,
+                                is_zst,
+                                type_id,
+                                &*inspectable_registry,
+                                type_registry,
+                                ui,
+                                self.ui_ctx,
+                                id,
+                            )
+                        })
+                    },
+                );
 
                 if result.is_err() {
-                    ui.label("This component is neither `Reflect` nor `Inspectable`.\nMake sure to also call `app.register_type` or `app.register_inspectable`.");
+                    no_inspectable_error_message(ui);
                 }
 
                 result.unwrap_or(false)
@@ -511,10 +514,7 @@ fn display_by_reflection(
     let reflect_component = match registration.data::<ReflectComponent>() {
         Some(reflect_component) => reflect_component,
         None => {
-            ui.label(format!(
-                "`{}` implements reflect, but does not have a `#[reflect(Component)` attribute.",
-                registration.short_name(),
-            ));
+            reflection_error_message(ui, registration);
 
             return Ok(false);
         }
@@ -539,6 +539,41 @@ fn display_by_reflection(
     ))
 }
 
+macro_rules! layout_job {
+    ( $($kind:ident $text:expr),* $(,)?) => {{
+        let mut job = egui::epaint::text::LayoutJob::default();
+        $(
+            job.append(
+                $text,
+                0.0,
+                egui::TextFormat {
+                    style: egui::TextStyle::$kind,
+                    ..Default::default()
+                },
+            );
+        )*
+        job
+    }}
+}
+
+fn reflection_error_message(ui: &mut egui::Ui, registration: &TypeRegistration) {
+    let job = layout_job!(
+        Monospace registration.short_name(), Body " implements ", Monospace "Reflect",
+        Body ", but does not have a ", Monospace "#[reflect(Component)]", Body " attribute.",
+    );
+
+    ui.label(job);
+}
+
+fn no_inspectable_error_message(ui: &mut egui::Ui) {
+    let job = layout_job!(
+        Body "This component is neither ", Monospace "Reflect", Body " nor ", Monospace "Inspectable",
+        Body ".\nMake sure to also call ", Monospace "app.register_type", Body " or ", Monospace "app.register_inspectable", Body ".",
+    );
+
+    ui.label(job);
+}
+
 // copied from bevy
 #[inline]
 unsafe fn get_component_and_ticks(
